#  tests for uwsgi-2.0.21-py310h45069db_1 (this is a generated file);
print('===== testing package: uwsgi-2.0.21-py310h45069db_1 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
# this test just makes sure we have the uwsgidecorators python module
try:
    import uwsgidecorators
except ImportError as e:
    # this is the expected behavior
    assert str(e).replace("'", "") == 'No module named uwsgi'
else:
    raise EnvironmentError("uwsgidecorators didn't import correctly")
#  --- run_test.py (end) ---

print('===== uwsgi-2.0.21-py310h45069db_1 OK =====');
